@@ -8,11 +8,11 @@
 #ifndef KGRSOUNDS_H
 #define KGRSOUNDS_H
 
+#include <QList>
 #include <QObject>
-#include <QVector>
 #include <QElapsedTimer>
 
-#include <KgSound>
+#include <KGameSound>
 
 class KGrSounds : public QObject
 {
@@ -68,10 +68,10 @@ public:
     void setVolume (int effect, qreal volume);
 
 private:
-    QVector<KgSound *> sounds;
-    QVector<int>       startTime;	// Start times of timed sounds, else 0.
-    bool               muted;
-    QElapsedTimer              t;
+    QList<KGameSound *> sounds;
+    QList<int>       startTime;	// Start times of timed sounds, else 0.
+    bool             muted;
+    QElapsedTimer    t;
 };
 
 #endif // KGRSOUNDS_H
